summaryrefslogtreecommitdiffstats
path: root/core
diff options
context:
space:
mode:
authorSimon Wilson <simonwilson@google.com>2011-03-21 16:58:41 -0700
committerAndroid (Google) Code Review <android-gerrit@google.com>2011-03-21 16:58:41 -0700
commit1ba4897e89fc30042a086b26755dfdb80af258dd (patch)
treeb702d811caa77c2214024b983ea25d33e12a2ea6 /core
parent661e9b371fcc1a2aec5dfd74f2cc65db1d8a77d5 (diff)
parent081148dd3238e73701a7579c2d869e588313ccd0 (diff)
downloadframeworks_base-1ba4897e89fc30042a086b26755dfdb80af258dd.zip
frameworks_base-1ba4897e89fc30042a086b26755dfdb80af258dd.tar.gz
frameworks_base-1ba4897e89fc30042a086b26755dfdb80af258dd.tar.bz2
Merge "DO NOT MERGE Change WiMAX indicator display" into gingerbread
Diffstat (limited to 'core')
-rw-r--r--core/java/android/net/wimax/WimaxManagerConstants.java58
-rw-r--r--core/res/res/drawable-hdpi/stat_sys_data_wimax_signal_3_fully.pngbin0 -> 2219 bytes
-rw-r--r--core/res/res/drawable-hdpi/stat_sys_data_wimax_signal_disconnected.pngbin0 -> 1807 bytes
3 files changed, 38 insertions, 20 deletions
diff --git a/core/res/res/drawable-hdpi/stat_sys_data_wimax_signal_3_fully.png b/core/res/res/drawable-hdpi/stat_sys_data_wimax_signal_3_fully.png
new file mode 100644
index 0000000..c2e4b78
--- /dev/null
+++ b/core/res/res/drawable-hdpi/stat_sys_data_wimax_signal_3_fully.png
Binary files differ
diff --git a/core/res/res/drawable-hdpi/stat_sys_data_wimax_signal_disconnected.png b/core/res/res/drawable-hdpi/stat_sys_data_wimax_signal_disconnected.png
new file mode 100644
index 0000000..51b839f
--- /dev/null
+++ b/core/res/res/drawable-hdpi/stat_sys_data_wimax_signal_disconnected.png
Binary files differ
diff --git a/core/java/android/net/wimax/WimaxManagerConstants.java b/core/java/android/net/wimax/WimaxManagerConstants.java
index 72e63b9..5ec4e96 100644
--- a/core/java/android/net/wimax/WimaxManagerConstants.java
+++ b/core/java/android/net/wimax/WimaxManagerConstants.java
@@ -10,15 +10,15 @@ public class WimaxManagerConstants
* Used by android.net.wimax.WimaxManager for handling management of
* Wimax access.
*/
- public static final String WIMAX_SERVICE="WiMax";
+ public static final String WIMAX_SERVICE = "WiMax";
/**
* Broadcast intent action indicating that Wimax has been enabled, disabled,
* enabling, disabling, or unknown. One extra provides this state as an int.
* Another extra provides the previous state, if available.
*/
- public static final String WIMAX_STATUS_CHANGED_ACTION
- = "android.net.wimax.WIMAX_STATUS_CHANGED";
+ public static final String WIMAX_ENABLED_STATUS_CHANGED =
+ "android.net.wimax.WIMAX_STATUS_CHANGED";
/**
* The lookup key for an int that indicates whether Wimax is enabled,
@@ -27,16 +27,38 @@ public class WimaxManagerConstants
public static final String EXTRA_WIMAX_STATUS = "wimax_status";
/**
- * Broadcast intent action indicating that Wimax data has been recieved, sent. One extra
- * provides the state as int.
+ * Broadcast intent action indicating that Wimax state has been changed
+ * state could be scanning, connecting, connected, disconnecting, disconnected
+ * initializing, initialized, unknown and ready. One extra provides this state as an int.
+ * Another extra provides the previous state, if available.
+ */
+ public static final String WIMAX_STATE_CHANGED_ACTION =
+ "android.net.wimax.WIMAX_STATE_CHANGE";
+
+ /**
+ * Broadcast intent action indicating that Wimax signal level has been changed.
+ * Level varies from 0 to 3.
+ */
+ public static final String SIGNAL_LEVEL_CHANGED_ACTION =
+ "android.net.wimax.SIGNAL_LEVEL_CHANGED";
+
+ /**
+ * The lookup key for an int that indicates whether Wimax state is
+ * scanning, connecting, connected, disconnecting, disconnected
+ * initializing, initialized, unknown and ready.
*/
- public static final String WIMAX_DATA_USED_ACTION = "android.net.wimax.WIMAX_DATA_USED";
+ public static final String EXTRA_WIMAX_STATE = "WimaxState";
/**
* The lookup key for an int that indicates whether Wimax is data is being recieved or sent,
* up indicates data is being sent and down indicates data being recieved.
*/
- public static final String EXTRA_UP_DOWN_DATA = "upDownData";
+ public static final String EXTRA_WIMAX_STATE_DETAIL = "WimaxStateDetail";
+
+ /**
+ * The lookup key for an int that indicates Wimax signal level.
+ */
+ public static final String EXTRA_NEW_SIGNAL_LEVEL = "newSignalLevel";
/**
* Indicatates Wimax is disabled.
@@ -64,22 +86,18 @@ public class WimaxManagerConstants
public static final int WIMAX_DEREGISTRATION = 8;
/**
- * Indicatates no data on wimax.
- */
- public static final int NO_DATA = 0;
-
- /**
- * Indicatates data is being sent.
+ * Indicatates wimax state is unknown.
*/
- public static final int UP_DATA = 1;
+ public static final int WIMAX_STATE_UNKNOWN = 0;
/**
- * Indicatates dats is being revieved.
+ * Indicatates wimax state is connected.
*/
- public static final int DOWN_DATA = 2;
+ public static final int WIMAX_STATE_CONNECTED = 7;
/**
- * Indicatates data is being recieved and sent simultaneously.
+ * Indicatates wimax state is disconnected.
*/
- public static final int UP_DOWN_DATA = 3;
+ public static final int WIMAX_STATE_DISCONNECTED = 9;
+
}
@@ -27,16 +27,38 @@ public class WimaxManagerConstants
/**
- * The lookup key for an int that indicates whether Wimax is data is being recieved or sent,
- * up indicates data is being sent and down indicates data being recieved.
+ * The lookup key for an int that indicates whether state of Wimax
+ * is idle.
*/